RDA
===

.. currentmodule:: xeofs.cross

.. autoclass:: RDA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RDA.__init__
      ~RDA.components
      ~RDA.compute
      ~RDA.correlation_coefficients_X
      ~RDA.correlation_coefficients_Y
      ~RDA.cross_correlation_coefficients
      ~RDA.deserialize
      ~RDA.fit
      ~RDA.fraction_variance_X_explained_by_X
      ~RDA.fraction_variance_Y_explained_by_X
      ~RDA.fraction_variance_Y_explained_by_Y
      ~RDA.get_params
      ~RDA.get_serialization_attrs
      ~RDA.heterogeneous_patterns
      ~RDA.homogeneous_patterns
      ~RDA.inverse_transform
      ~RDA.load
      ~RDA.predict
      ~RDA.save
      ~RDA.scores
      ~RDA.serialize
      ~RDA.squared_covariance_fraction
      ~RDA.transform
   
   

   
   
   